;**************************************************************************
;*                             Garaz Receiver                             *
;**************************************************************************
;*                                                                        *
;**************************************************************************
;*          v 1.11 - 30.01.2012                                           *
;**************************************************************************
;*          Hardw.: PIC16F627A used                                       *
;*          OSC.......: Internal osc. used                                *
;*          POWER.....:  7805                                             *
;**************************************************************************

W                            EQU     H'0000'
F                            EQU     H'0001'

dd2			EQU D'060'

;----- Register Files------------------------------------------------------

INDF                         EQU     H'0000'
TMR0                         EQU     H'0001'
PCL                          EQU     H'0002'
STATUS                       EQU     H'0003'
FSR                          EQU     H'0004'
PORTA                        EQU     H'0005'
PORTB                        EQU     H'0006'

INTCON                       EQU     H'000B'
OPTION_REG                   EQU     H'0081'
TRISA                        EQU     H'0085'
TRISB                        EQU     H'0086'
CMCON                        EQU     H'001F'

;----- STATUS Bits --------------------------------------------------------
IRP                          EQU     H'0007'
RP1                          EQU     H'0006'
RP0                          EQU     H'0005'
NOT_TO                       EQU     H'0004'
NOT_PD                       EQU     H'0003'
Z                            EQU     H'0002'
DC                           EQU     H'0001'
C                            EQU     H'0000'

;==========================================================================
;
;       RAM Definition
;
;==========================================================================

    __MAXRAM H'01FF'
    __BADRAM H'07'-H'09', H'0D', H'13'-H'14', H'1B'-H'1E'
    __BADRAM H'87'-H'89', H'8D', H'8F'-H'91', H'93'-H'97', H'9E'
    __BADRAM H'105', H'107'-H'109', H'10C'-H'11F', H'150'-H'16F'
    __BADRAM H'185', H'187'-H'189', H'18C'-H'1EF'

;==========================================================================
;
;       Configuration Bits
;
;==========================================================================

_BODEN_ON                    EQU     H'3FFF'
_BODEN_OFF                   EQU     H'3FBF'
_CP_ALL                      EQU     H'03FF'
_CP_75                       EQU     H'17FF'
_CP_50                       EQU     H'2BFF'
_CP_OFF                      EQU     H'3FFF'
_DATA_CP_ON                  EQU     H'3EFF'
_DATA_CP_OFF                 EQU     H'3FFF'
_PWRTE_OFF                   EQU     H'3FFF'
_PWRTE_ON                    EQU     H'3FF7'
_WDT_ON                      EQU     H'3FFF'
_WDT_OFF                     EQU     H'3FFB'
_LVP_ON                      EQU     H'3FFF'
_LVP_OFF                     EQU     H'3F7F'
_MCLRE_ON                    EQU     H'3FFF'
_MCLRE_OFF                   EQU     H'3FDF'
_ER_OSC_CLKOUT               EQU     H'3FFF'
_ER_OSC_NOCLKOUT             EQU     H'3FFE'
_INTRC_OSC_CLKOUT            EQU     H'3FFD'
_INTRC_OSC_NOCLKOUT          EQU     H'3FFC'
_EXTCLK_OSC                  EQU     H'3FEF'
_LP_OSC                      EQU     H'3FEC'
_XT_OSC                      EQU     H'3FED'
_HS_OSC                      EQU     H'3FEE'

	__CONFIG        _BODEN_OFF & _CP_OFF & _DATA_CP_OFF & _PWRTE_ON & _WDT_OFF & _LVP_OFF & _MCLRE_OFF & _INTRC_OSC_NOCLKOUT

;==========================================================================
;       Variable Definition
;==========================================================================
;INPUTS
SW1		EQU     H'00'		;SW1 is triggering RA0
SW2		EQU     H'01'		;SW2 is triggering RA1
SW3		EQU     H'02'		;SW3 is triggering RA2
SW4		EQU     H'03'		;SW4 is triggering RA3
TIMER1		EQU	H'20'		;Used in delay routine
TIMER2		EQU	H'21'		; "	"	"	

last_s		EQU	H'22'
;-------------------------------------------------------------------
;always exactly one bit of stage bytes is set to 1 - current stage
stage1		EQU	H'23'		;stage bits1
stage2		EQU	H'24'		;stage bits2
stage3		EQU	H'25'		;stage bits3
;-------------------------------------------------------------------
ttsc1		EQU	H'26'		;time-to-send counter
ttsc2		EQU	H'27'
ttsc3		EQU	H'28'
;-------------------------------------------------------------------
v_send		EQU	H'29'
;
lcc1		EQU	H'2A'
lcc2		EQU	H'2B'
;
ds1		EQU	H'2C'
ds2		EQU	H'2D'
ds3		EQU	H'2E'
;
wdt1		EQU	H'2F'
wdt2		EQU	H'30'
wdt3		EQU	H'31'
wdt4		EQU	H'32'

signal_lost	EQU	H'33'

lcx1		EQU	H'34'
lcx2		EQU	H'35'
bbb		EQU	H'36'

fcela		EQU	H'37'
;==========================================================================

		ORG	0		;Reset vector address
		GOTO	RESET		;goto RESET routine when boot.



;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX


;	       **********************************
;              **  RESET :  main boot routine  **
;              **********************************

RESET		MOVLW	B'00000111'	;Disable Comparator module's
		MOVWF	CMCON
		;
		BSF	STATUS,RP0	;Switch to register bank 1
					;Disable pull-ups
					;INT on rising edge
					;TMR0 to CLKOUT
					;TMR0 Incr low2high trans.
					;Prescaler assign to Timer0
					;Prescaler rate is 1:256
		MOVLW	B'11010111'	;Set PIC options (See datasheet).
		MOVWF	OPTION_REG	;Write the OPTION register.
		;
		CLRF	INTCON		;Disable interrupts
		MOVLW	B'00000000'	;1 = input; 0 = output
		MOVWF	TRISB		;RBx
		MOVLW	B'01111111'	;1 = input; 0 = output
		MOVWF	TRISA		;RAx
		BCF	STATUS,RP0	;Switch Back to reg. Bank 0

; XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
; XXXXXXXXXX       main            XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
; XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX


		clrf	fcela

		clrf	PORTA

		call	test01

		call	set_ds1_off
		call	set_ds2_red
		call	set_ds3_off
		bsf	PORTB,D'001'		;sound off
		bsf	PORTB,D'000'		;no signal

		call	clear_wdt


;-------------------------------------------------------------------------------
;initial stage - wait for first signal
main2
		btfsc	PORTA,D'000'
		goto	g_statusA2		;signal "status A" received
		btfsc	PORTA,D'002'
		goto	g_statusB2		;signal "status B" received
		btfsc	PORTA,D'004'
		goto	g_statusC2		;signal "status C" received

		call	inc_wdt

		goto	main2


g_statusA2	clrf	fcela
		bcf	PORTB,D'001'		;sound on
		goto	g_statusA
g_statusB2	clrf	fcela
		bcf	PORTB,D'001'		;sound on
		goto	g_statusB
g_statusC2	clrf	fcela
		bcf	PORTB,D'001'		;sound on
		goto	g_statusC
;-------------------------------------------------------------------------------
;main stage - wait for signal
main
		btfsc	PORTA,D'000'
		goto	g_statusA		;signal "status A" received
		btfsc	PORTA,D'002'
		goto	g_statusB		;signal "status B" received
		btfsc	PORTA,D'004'
		goto	g_statusC		;signal "status C" received

		call	inc_wdt

		goto	main


;------------------------------------------------------------------------------------
;------------------------------------------------------------------------------------
;------------------------------------------------------------------------------------

g_statusA	call	dr3
		call	clear_wdt
		call	s1_service

		bcf	PORTB,D'000'		;signal received
		btfsc	PORTA,D'001'
		goto	e_stage01
		goto	e_stage11

g_statusB	call	dr3
		call	clear_wdt

		call	s1_service
		bcf	PORTB,D'000'		;signal received
		btfsc	PORTA,D'003'
		goto	e_stage02
		goto	e_stage12

g_statusC	call	dr3
		call	clear_wdt

		call	s1_service
		bcf	PORTB,D'000'		;signal received
		btfsc	PORTA,D'005'
		goto	e_stage03
		goto	e_stage13

;------------------------------------------------------------------------------------
;------------------------------------------------------------------------------------
;------------------------------------------------------------------------------------

;-----------------------------------------------------------------------------
e_stage01	call	set_ds1_green
		call	set_ds2_green
		call	set_ds3_green

		bcf	PORTA,D'007'

		goto	main
;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------
e_stage11	movlw	dd2
		movwf	lcc1
		movlw	D'255'
		movwf	lcc2

		btfss	fcela,D'000'		;sound if off?
		bsf	PORTA,D'007'
;
		call	set_ds1_green
		call	set_ds2_green
		call	set_ds3_green
		clrf	ds1
		call	toggle_ds1

e_stage11m	btfsc	PORTA,D'000'
		goto	g_statusA		;signal "status A" received
		btfsc	PORTA,D'002'
		goto	g_statusB		;signal "status B" received
		btfsc	PORTA,D'004'
		goto	g_statusC		;signal "status C" received

		decfsz	lcc1
		goto	gl001
		movlw	dd2
		movwf	lcc1
		decfsz	lcc2
		goto	gl001
		movlw	D'255'
		movwf	lcc2

		call	toggle_ds1

gl001		call	inc_wdt
		goto	e_stage11m

;-----------------------------------------------------------------------------
;----------------------------------------------------------------------
e_stage02
		call	set_ds1_red
		call	set_ds2_red
		call	set_ds3_green

		btfss	fcela,D'000'		;sound if off?
		bsf	PORTA,D'007'

		goto	main
;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------
e_stage12	movlw	dd2
		movwf	lcc1
		movlw	D'255'
		movwf	lcc2

		btfss	fcela,D'000'		;sound if off?
		bsf	PORTA,D'007'
;
		call	set_ds1_red
		call	set_ds2_red
		call	set_ds3_green
		clrf	ds2
		call	toggle_ds2

e_stage12m	btfsc	PORTA,D'000'
		goto	g_statusA		;signal "status A" received
		btfsc	PORTA,D'002'
		goto	g_statusB		;signal "status B" received
		btfsc	PORTA,D'004'
		goto	g_statusC		;signal "status C" received

		decfsz	lcc1
		goto	gl002
		movlw	dd2
		movwf	lcc1
		decfsz	lcc2
		goto	gl002
		movlw	D'255'
		movwf	lcc2

		call	toggle_ds2

gl002		call	inc_wdt
		goto	e_stage12m

;----------------------------------------------------------------------
e_stage03	call	set_ds1_red
		call	set_ds2_red
		call	set_ds3_red

		btfss	fcela,D'000'		;sound if off?
		bsf	PORTA,D'007'

		goto	main
;----------------------------------------------------------------------
e_stage13	movlw	dd2
		movwf	lcc1
		movlw	D'255'
		movwf	lcc2

		btfss	fcela,D'000'		;sound if off?
		bsf	PORTA,D'007'
;
		call	set_ds1_red
		call	set_ds2_red
		call	set_ds3_red
		clrf	ds3
		call	toggle_ds3

e_stage13m	btfsc	PORTA,D'000'
		goto	g_statusA		;signal "status A" received
		btfsc	PORTA,D'002'
		goto	g_statusB		;signal "status B" received
		btfsc	PORTA,D'004'
		goto	g_statusC		;signal "status C" received

		decfsz	lcc1
		goto	gl003
		movlw	dd2
		movwf	lcc1
		decfsz	lcc2
		goto	gl003
		movlw	D'255'
		movwf	lcc2

		call	toggle_ds3

gl003		call	inc_wdt
		goto	e_stage13m

;----------------------------------------------------------------------
;----------------------------------------------------------------------
;----------------------------------------------------------------------
set_ds1_green	bcf	PORTB,D'003'
		bsf	PORTB,D'002'
		return
;----------------------------------------------------------------------
set_ds1_red	bcf	PORTB,D'002'
		bsf	PORTB,D'003'
		return
;----------------------------------------------------------------------
set_ds1_off	bcf	PORTB,D'003'
		bcf	PORTB,D'002'
		return
;----------------------------------------------------------------------
set_ds2_green	bcf	PORTB,D'005'
		bsf	PORTB,D'004'
		return
;----------------------------------------------------------------------
set_ds2_red	bcf	PORTB,D'004'
		bsf	PORTB,D'005'
		return
;----------------------------------------------------------------------
set_ds2_off	bcf	PORTB,D'005'
		bcf	PORTB,D'004'
		return
;----------------------------------------------------------------------
set_ds3_green	bcf	PORTB,D'007'
		bsf	PORTB,D'006'
		return
;----------------------------------------------------------------------
set_ds3_red	bcf	PORTB,D'006'
		bsf	PORTB,D'007'
		return
;----------------------------------------------------------------------
set_ds3_off	bcf	PORTB,D'007'
		bcf	PORTB,D'006'
		return
;---------------------------------------------------------------------
toggle_ds1	btfss	ds1,D'000'
		goto	ds1_gg
		call	set_ds1_red
		bcf	ds1,D'000'
		return
ds1_gg		call	set_ds1_green
		bsf	ds1,D'000'
		return
;---------------------------------------------------------------------
toggle_ds2	btfss	ds2,D'000'
		goto	ds2_gg
		call	set_ds2_red
		bcf	ds2,D'000'
		return
ds2_gg		call	set_ds2_green
		bsf	ds2,D'000'
		return
;---------------------------------------------------------------------
toggle_ds3	btfss	ds3,D'000'
		goto	ds3_gg
		call	set_ds3_red
		bcf	ds3,D'000'
		return
ds3_gg		call	set_ds3_green
		bsf	ds3,D'000'
		return
;---------------------------------------------------------------------
toggle_blue	btfss	bbb,D'000'
		goto	dbb_gg
		bsf	PORTB,D'000'
		bcf	bbb,D'000'
		return
dbb_gg		bcf	PORTB,D'000'
		bsf	bbb,D'000'
		return

;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

;		*********************************************
;		*               delay routine               *
;		*********************************************

DELAY_ROUTINE	MOVLW   D'100'
DELAY_ROUTINE2	MOVWF   TIMER2
DEL_LOOP1       MOVLW   D'255'
		MOVWF   TIMER1
DEL_LOOP2       DECFSZ  TIMER1,F
                GOTO    DEL_LOOP2
                DECFSZ  TIMER2,F
                GOTO    DEL_LOOP1
		return
;-----------------------------------------------------------------------
dr3		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		return
;-----------------------------------------------------------------------


;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;initialize time-to-send counter
init_ttsc	movlw	D'255'
		movwf	ttsc1
		movwf	ttsc2
		movlw	D'010'
		movwf	ttsc3
		return
;----------------------------------------------------------------------------
;decrement time-to-send counter
ddtsc		clrf	v_send
		DECFSZ  ttsc1,F
		return
		movlw	D'255'
		movwf	ttsc1
		DECFSZ  ttsc2,F
		return
		movlw	D'255'
		movwf	ttsc2
		DECFSZ  ttsc3,F
		return
		call	init_ttsc
		bsf	v_send,D'000'
		return
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------

;------------------------------------------------------------------------------------
;------------------------------------------------------------------------------------
;------------------------------------------------------------------------------------
test01		clrf	PORTB
		bsf	PORTB,D'000'
		call	dr3
		bcf	PORTB,D'000'
		call	dr3

		bsf	PORTB,D'000'
		call	dr3
		bcf	PORTB,D'000'
		call	dr3

		bsf	PORTB,D'000'
		call	dr3
		bcf	PORTB,D'000'
		call	dr3

		bsf	PORTB,D'000'
		call	dr3
		bcf	PORTB,D'000'
		call	dr3

		bsf	PORTB,D'000'
		call	dr3
		bcf	PORTB,D'000'
		call	dr3

		clrf	PORTB


		call	set_ds1_green
		call	dr3
		call	set_ds1_red
		call	dr3
		call	set_ds1_off
		call	dr3
		call	set_ds2_green
		call	dr3
		call	set_ds2_red
		call	dr3
		call	set_ds2_off
		call	dr3
		call	set_ds3_green
		call	dr3
		call	set_ds3_red
		call	dr3
		call	set_ds3_off
		call	dr3

		return
;--------------------------------------------------------------------
clear_wdt	clrf	wdt1
		clrf	wdt2
		movlw	D'230'
		movwf	wdt3
		bcf	PORTB,D'000'
		clrf	signal_lost
		return
;--------------------------------------------------------------------
;--------------------------------------------------------------------
;   increment watch dog timer
;--------------------------------------------------------------------
inc_wdt		btfsc	signal_lost,D'000'
		call	b_blink
		incfsz	wdt1,1
		goto	s1_service
		incfsz	wdt2,1
		goto	s1_service
		incfsz	wdt3,1
		goto	s1_service

;		bsf	PORTB,D'001'		;not used here...
		bsf	signal_lost,D'000'
;---------------------------------------------------
;obsluha tlacitka
s1_service	btfss	PORTA,D'006'
;ak sme tu, je tlacitko stlacene
		goto	s1_pressed
;ak sme tu, je tlacitko pustene
		bcf	fcela,D'007'		;tlacitko pustene
		return
;---------------------------------------------------
s1_pressed	btfsc	fcela,D'007'
		return				;bolo stlacene aj pred tym --> exit
;toggle: sound on/off
		movlw	B'00000001'
		xorwf	fcela,1

		bcf	PORTA,D'007'		;at toggle - always current sound off ---

		bcf	PORTB,D'001'
		btfsc	fcela,D'000'
		bsf	PORTB,D'001'

		bsf	fcela,D'007'
		return

;--------------------------------------------------------------------
;--------------------------------------------------------------------
;--------------------------------------------------------------------
b_blink		decfsz	lcx1
		goto	gx002
		movlw	D'255'
		movwf	lcx1
		decfsz	lcx2
		goto	gx002
		movlw	D'050'
		movwf	lcx2

		call	toggle_blue

gx002		return		
;--------------------------------------------------------------------

		END