;**************************************************************************
;*                             Garaz                                      *
;**************************************************************************
;*                                                                        *
;**************************************************************************
;*          v 1.10 - 24.01.2012                                           *
;**************************************************************************
;*          Hardw.: PIC16F627A used                                       *
;*          OSC.......: Internal osc. used                                *
;*          POWER.....:  7805 ( + 7812 for remote control )               *
;**************************************************************************

W                            EQU     H'0000'
F                            EQU     H'0001'

;----- Register Files------------------------------------------------------

INDF                         EQU     H'0000'
TMR0                         EQU     H'0001'
PCL                          EQU     H'0002'
STATUS                       EQU     H'0003'
FSR                          EQU     H'0004'
PORTA                        EQU     H'0005'
PORTB                        EQU     H'0006'

INTCON                       EQU     H'000B'
OPTION_REG                   EQU     H'0081'
TRISA                        EQU     H'0085'
TRISB                        EQU     H'0086'
CMCON                        EQU     H'001F'

;----- STATUS Bits --------------------------------------------------------
IRP                          EQU     H'0007'
RP1                          EQU     H'0006'
RP0                          EQU     H'0005'
NOT_TO                       EQU     H'0004'
NOT_PD                       EQU     H'0003'
Z                            EQU     H'0002'
DC                           EQU     H'0001'
C                            EQU     H'0000'

;==========================================================================
;
;       RAM Definition
;
;==========================================================================

    __MAXRAM H'01FF'
    __BADRAM H'07'-H'09', H'0D', H'13'-H'14', H'1B'-H'1E'
    __BADRAM H'87'-H'89', H'8D', H'8F'-H'91', H'93'-H'97', H'9E'
    __BADRAM H'105', H'107'-H'109', H'10C'-H'11F', H'150'-H'16F'
    __BADRAM H'185', H'187'-H'189', H'18C'-H'1EF'

;==========================================================================
;
;       Configuration Bits
;
;==========================================================================

_BODEN_ON                    EQU     H'3FFF'
_BODEN_OFF                   EQU     H'3FBF'
_CP_ALL                      EQU     H'03FF'
_CP_75                       EQU     H'17FF'
_CP_50                       EQU     H'2BFF'
_CP_OFF                      EQU     H'3FFF'
_DATA_CP_ON                  EQU     H'3EFF'
_DATA_CP_OFF                 EQU     H'3FFF'
_PWRTE_OFF                   EQU     H'3FFF'
_PWRTE_ON                    EQU     H'3FF7'
_WDT_ON                      EQU     H'3FFF'
_WDT_OFF                     EQU     H'3FFB'
_LVP_ON                      EQU     H'3FFF'
_LVP_OFF                     EQU     H'3F7F'
_MCLRE_ON                    EQU     H'3FFF'
_MCLRE_OFF                   EQU     H'3FDF'
_ER_OSC_CLKOUT               EQU     H'3FFF'
_ER_OSC_NOCLKOUT             EQU     H'3FFE'
_INTRC_OSC_CLKOUT            EQU     H'3FFD'
_INTRC_OSC_NOCLKOUT          EQU     H'3FFC'
_EXTCLK_OSC                  EQU     H'3FEF'
_LP_OSC                      EQU     H'3FEC'
_XT_OSC                      EQU     H'3FED'
_HS_OSC                      EQU     H'3FEE'

	__CONFIG        _BODEN_OFF & _CP_OFF & _DATA_CP_OFF & _PWRTE_ON & _WDT_OFF & _LVP_OFF & _MCLRE_OFF & _INTRC_OSC_NOCLKOUT

;==========================================================================
;       Variable Definition
;==========================================================================
;INPUTS
SW1		EQU     H'00'		;SW1 is triggering RA0
SW2		EQU     H'01'		;SW2 is triggering RA1
SW3		EQU     H'02'		;SW3 is triggering RA2
SW4		EQU     H'03'		;SW4 is triggering RA3
TIMER1		EQU	H'20'		;Used in delay routine
TIMER2		EQU	H'21'		; "	"	"	

last_s		EQU	H'22'
;-------------------------------------------------------------------
;always exactly one bit of stage bytes is set to 1 - current stage
stage1		EQU	H'23'		;stage bits1
stage2		EQU	H'24'		;stage bits2
stage3		EQU	H'25'		;stage bits3
;-------------------------------------------------------------------
ttsc1		EQU	H'26'		;time-to-send counter
ttsc2		EQU	H'27'
ttsc3		EQU	H'28'
;-------------------------------------------------------------------
v_send		EQU	H'29'
;
lcc1		EQU	H'2A'
lcc2		EQU	H'2B'
;
ds1		EQU	H'2C'
ds2		EQU	H'2D'
ds3		EQU	H'2E'
;
;==========================================================================

		ORG	0		;Reset vector address
		GOTO	RESET		;goto RESET routine when boot.



;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX


;	       **********************************
;              **  RESET :  main boot routine  **
;              **********************************

RESET		MOVLW	B'00000111'	;Disable Comparator module's
		MOVWF	CMCON
		;
		BSF	STATUS,RP0	;Switch to register bank 1
					;Disable pull-ups
					;INT on rising edge
					;TMR0 to CLKOUT
					;TMR0 Incr low2high trans.
					;Prescaler assign to Timer0
					;Prescaler rate is 1:256
		MOVLW	B'11010111'	;Set PIC options (See datasheet).
		MOVWF	OPTION_REG	;Write the OPTION register.
		;
		CLRF	INTCON		;Disable interrupts
		MOVLW	B'00000000'	;1 = input; 0 = output
		MOVWF	TRISB		;RBx
		MOVLW	B'01110000'	;1 = input; 0 = output
		MOVWF	TRISA		;RAx
		BCF	STATUS,RP0	;Switch Back to reg. Bank 0

; XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
; XXXXXXXXXX       main            XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
; XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

;init -----------------------------------------------------------------------
		clrf	PORTA
		clrf	PORTB

		call	clear_all
		clrf	last_s
		clrf	stage1
		clrf	stage2
		clrf	stage3

		call	init_ttsc

		call	tmp01
;test -----------------------------------------------------------------------
;test1 - door stage indicator LEDs
		call	set_ds1_red
		call	dr3
		call	set_ds1_green
		call	dr3
		call	set_ds2_red
		call	dr3
		call	set_ds2_green
		call	dr3
		call	set_ds3_red
		call	dr3
		call	set_ds3_green
		call	dr3

		call	set_ds1_off
		call	set_ds2_off
		call	set_ds3_off
;test2 - 7-seg. disp
;............
;
		movlw	B'10000001'
		movwf	PORTB
		call	dr3
		movlw	B'10000010'
		movwf	PORTB
		call	dr3
		movlw	B'10000100'
		movwf	PORTB
		call	dr3
		movlw	B'10001000'
		movwf	PORTB
		call	dr3
		movlw	B'10010000'
		movwf	PORTB
		call	dr3
		movlw	B'10100000'
		movwf	PORTB
		call	dr3
		movlw	B'11000000'
		movwf	PORTB
		call	dr3
		movlw	B'10000000'
		movwf	PORTB
		call	dr3
;----------------------------------------------------------------------------

		call	w_E
main
;analyze sensors
		call	get_stage
;
		btfsc	stage3,D'007'
		goto	e_error			;error
		btfsc	stage3,D'006'		;no active sensor
		goto	e_error2
		btfsc	stage1,D'000'
		goto	e_stage01		;stage01

		btfsc	stage1,D'001'
		goto	e_stage02		;stage02

		btfsc	stage1,D'002'
		goto	e_stage03		;stage03


		goto	main
;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------
; xxxxxxxxxxxxxxxxxxxxxx STAGES xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------
e_error		call	w_E
		call	set_ds1_off
		call	set_ds2_red
		call	set_ds3_off

		goto	main
;-----------------------------------------------------------------------------
e_error2	call	w_E2
		call	set_ds1_off
		call	set_ds2_red
		call	set_ds3_off

		goto	main
;-----------------------------------------------------------------------------
e_stage01	call	send_stage01
;
		call	w_C
		call	set_ds1_green
		call	set_ds2_green
		call	set_ds3_green

e_stage01m	call	ddtsc
		btfsc	v_send,D'000'
		call	send_stage01

		btfsc	PORTA,D'006'
		goto	e_stage11			;sensor RA6 is not active anymore --> leaving stage01 to stage11

		goto	e_stage01m
;-----------------------------------------------------------------------------
e_stage02	call	send_stage02

		call	w_o
		call	set_ds1_green
		call	set_ds2_red
		call	set_ds3_red

e_stage02m	call	ddtsc
		btfsc	v_send,D'000'
		call	send_stage02

		btfsc	PORTA,D'005'
		goto	e_stage12			;sensor RA6 is not active anymore --> leaving stage02 to stage12

		goto	e_stage02m
;-----------------------------------------------------------------------------
e_stage03	call	send_stage03

		call	w_O
		call	set_ds1_red
		call	set_ds2_red
		call	set_ds3_red


e_stage03m	call	ddtsc
		btfsc	v_send,D'000'
		call	send_stage03

		btfsc	PORTA,D'004'
		goto	e_stage13			;sensor RA4 is not active anymore --> leaving stage03 to stage13

		goto	e_stage03m
;-----------------------------------------------------------------------------
e_stage11	call	send_stage11
		movlw	D'255'
		movwf	lcc1
		movlw	D'100'
		movwf	lcc2
;
		call	w_o
		call	set_ds1_green
		call	set_ds2_green
		clrf	ds3
		call	toggle_ds3

e_stage11m	call	ddtsc
		btfsc	v_send,D'000'
		call	send_stage11

		decfsz	lcc1
		goto	gl001
		movlw	D'255'
		movwf	lcc1
		decfsz	lcc2
		goto	gl001
		movlw	D'100'
		movwf	lcc2
		call	toggle_ds3
gl001		btfss	PORTA,D'006'
		goto	e_stage01			;sensor RA6 becomes active --> back to stage01
		btfss	PORTA,D'005'
		goto	e_stage02			;sensor RA5 becomes active --> continue to stage02

		goto	e_stage11m
;-----------------------------------------------------------------------------
e_stage12	call	send_stage12
		movlw	D'255'
		movwf	lcc1
		movlw	D'100'
		movwf	lcc2
;
		call	w_o
		call	set_ds1_green
		clrf	ds2
		call	toggle_ds2

e_stage12m	call	ddtsc
		btfsc	v_send,D'000'
		call	send_stage12

		decfsz	lcc1
		goto	gl002
		movlw	D'255'
		movwf	lcc1
		decfsz	lcc2
		goto	gl002
		movlw	D'100'
		movwf	lcc2
		call	toggle_ds2
gl002		btfss	PORTA,D'006'
		goto	e_stage01			;sensor RA6 becomes active --> goto stage01
		btfss	PORTA,D'005'
		goto	e_stage02			;sensor RA5 becomes active --> goto stage02
		btfss	PORTA,D'004'
		goto	e_stage03			;sensor RS4 becomes active --> goto stage03

		goto	e_stage12m

;-----------------------------------------------------------------------------
e_stage13	call	send_stage13
		movlw	D'255'
		movwf	lcc1
		movlw	D'100'
		movwf	lcc2
;
		call	w_o
		clrf	ds1
		call	toggle_ds1

e_stage13m	call	ddtsc
		btfsc	v_send,D'000'
		call	send_stage13

		decfsz	lcc1
		goto	gl003
		movlw	D'255'
		movwf	lcc1
		decfsz	lcc2
		goto	gl003
		movlw	D'100'
		movwf	lcc2
		call	toggle_ds1
gl003		btfss	PORTA,D'006'
		goto	e_stage01			;sensor RA6 becomes active --> goto stage01
		btfss	PORTA,D'005'
		goto	e_stage02			;sensor RA5 becomes active --> goto stage02
		btfss	PORTA,D'004'
		goto	e_stage03			;sensor RS4 becomes active --> goto stage03

		goto	e_stage13m

;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------
send_stage01	call	A_on
		return
;---------------------------------------
send_stage02	call	B_on
		return
;---------------------------------------
send_stage03	call	C_on
		return
;---------------------------------------
send_stage11	call	A_off
		return
;---------------------------------------
send_stage12	call	B_off
		return
;---------------------------------------
send_stage13	call	C_off
		return
;---------------------------------------
;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------
qqq		call	tmp01

		call	A_on
		call	tmp01

		call	A_off
		call	tmp01

		call	B_on
		call	tmp01

		call	B_off
		call	tmp01

		call	C_on
		call	tmp01

		call	C_off
		call	tmp01


		goto	qqq
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;set required bit of 4099 on RA7 to 0/1

;W3    = 0/1 (required value)
;W0-2 = address

ra07		bsf	PORTB,D'007'		;RB7 = 1 (disabled)
		andlw	B'01001111'		;RA7 = 0 (enabled)
		movwf	PORTA
		nop
		nop
		bsf	PORTA,D'007'		;RA7 = 1 - disabled (write is finished)
		return
;----------------------------------------------------------------------
rb07		iorlw	B'10000000'		;RA7 = 1 (disabled)
		movwf	PORTA
		bcf	PORTB,D'007'		;RB7 = 1 (enabled)
		nop
		nop
		bsf	PORTB,D'007'		;RB7 = 1 - disabled (write is finished)
		return
;----------------------------------------------------------------------
A_on		call	A_on1
		call	dr3
		call	A_on2
		return

A_on1		movlw	B'00001000'
		call	ra07
		call	dr3
		movlw	B'00000000'
		call	ra07
		return

A_on2		movlw	B'00001000'
		call	ra07
		call	dr3s
		movlw	B'00000000'
		call	ra07
		return
;----------------------------------------------------------------------
A_off		call	A_off1
		call	dr3
		call	A_off2
		return

A_off1		movlw	B'00001001'
		call	ra07
		call	dr3
		movlw	B'00000001'
		call	ra07
		return

A_off2		movlw	B'00001001'
		call	ra07
		call	dr3s
		movlw	B'00000001'
		call	ra07
		return
;----------------------------------------------------------------------
B_on		call	B_on1
		call	dr3
		call	B_on2
		return

B_on1		movlw	B'00001010'
		call	ra07
		call	dr3
		movlw	B'00000010'
		call	ra07
		return

B_on2		movlw	B'00001010'
		call	ra07
		call	dr3s
		movlw	B'00000010'
		call	ra07
		return
;----------------------------------------------------------------------
B_off		call	B_off1
		call	dr3
		call	B_off2
		return

B_off1		movlw	B'00001011'
		call	ra07
		call	dr3
		movlw	B'00000011'
		call	ra07
		return

B_off2		movlw	B'00001011'
		call	ra07
		call	dr3s
		movlw	B'00000011'
		call	ra07
		return
;----------------------------------------------------------------------
C_on		call	C_on1
		call	dr3
		call	C_on2
		return

C_on1		movlw	B'00001100'
		call	ra07
		call	dr3
		movlw	B'00000100'
		call	ra07
		return

C_on2		movlw	B'00001100'
		call	ra07
		call	dr3s
		movlw	B'00000100'
		call	ra07
		return
;----------------------------------------------------------------------
C_off		call	C_off1
		call	dr3
		call	C_off2
		return

C_off1		movlw	B'00001101'
		call	ra07
		call	dr3
		movlw	B'00000101'
		call	ra07
		return

C_off2		movlw	B'00001101'
		call	ra07
		call	dr3s
		movlw	B'00000101'
		call	ra07
		return
;----------------------------------------------------------------------
set_ds1_green	movlw	B'00001000'
		call	rb07
		movlw	B'00000001'
		call	rb07
		return
;----------------------------------------------------------------------
set_ds1_red	movlw	B'00000000'
		call	rb07
		movlw	B'00001001'
		call	rb07
		return
;----------------------------------------------------------------------
set_ds1_off	movlw	B'00000000'
		call	rb07
		movlw	B'00000001'
		call	rb07
		return
;----------------------------------------------------------------------
set_ds2_green	movlw	B'00001010'
		call	rb07
		movlw	B'00000011'
		call	rb07
		return
;----------------------------------------------------------------------
set_ds2_red	movlw	B'00000010'
		call	rb07
		movlw	B'00001011'
		call	rb07
		return
;----------------------------------------------------------------------
set_ds2_off	movlw	B'00000010'
		call	rb07
		movlw	B'00000011'
		call	rb07
		return
;----------------------------------------------------------------------
set_ds3_green	movlw	B'00001100'
		call	rb07
		movlw	B'00000101'
		call	rb07
		return
;----------------------------------------------------------------------
set_ds3_red	movlw	B'00000100'
		call	rb07
		movlw	B'00001101'
		call	rb07
		return
;----------------------------------------------------------------------
set_ds3_off	movlw	B'00000100'
		call	rb07
		movlw	B'00000101'
		call	rb07
		return
;---------------------------------------------------------------------
toggle_ds1	btfss	ds1,D'000'
		goto	ds1_gg
		call	set_ds1_red
		bcf	ds1,D'000'
		return
ds1_gg		call	set_ds1_green
		bsf	ds1,D'000'
		return
;---------------------------------------------------------------------
toggle_ds2	btfss	ds2,D'000'
		goto	ds2_gg
		call	set_ds2_red
		bcf	ds2,D'000'
		return
ds2_gg		call	set_ds2_green
		bsf	ds2,D'000'
		return
;---------------------------------------------------------------------
toggle_ds3	btfss	ds3,D'000'
		goto	ds3_gg
		call	set_ds3_red
		bcf	ds3,D'000'
		return
ds3_gg		call	set_ds3_green
		bsf	ds3,D'000'
		return
;---------------------------------------------------------------------
w_E		movlw	B'11111001'
		movwf	PORTB
		return
;---------------------------------------------------------------------
w_E2		movlw	B'10010010'
		movwf	PORTB
		return
;---------------------------------------------------------------------
w_C		movlw	B'10111001'
		movwf	PORTB
		return
;---------------------------------------------------------------------
w_o		movlw	B'11011100'
		movwf	PORTB
		return
;---------------------------------------------------------------------
w_O		movlw	B'10111111'
		movwf	PORTB
		return
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

;		*********************************************
;		*               delay routine               *
;		*********************************************

DELAY_ROUTINE	MOVLW   D'100'
DELAY_ROUTINE2	MOVWF   TIMER2
DEL_LOOP1       MOVLW   D'255'
		MOVWF   TIMER1
DEL_LOOP2       DECFSZ  TIMER1,F
                GOTO    DEL_LOOP2
                DECFSZ  TIMER2,F
                GOTO    DEL_LOOP1
		return
;-----------------------------------------------------------------------
dr3		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		return
;-----------------------------------------------------------------------
dr3s		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		CALL	DELAY_ROUTINE
		return
;-----------------------------------------------------------------------
;-----------------------------------------------------------------------
clear_all	clrf	PORTB

		movlw	B'00000000'
		call	rb07
		movlw	B'00000001'
		call	rb07
		movlw	B'00000010'
		call	rb07
		movlw	B'00000011'
		call	rb07
		movlw	B'00000100'
		call	rb07
		movlw	B'00000101'
		call	rb07
		movlw	B'00000110'
		call	rb07
		movlw	B'00000111'
		call	rb07

		movlw	B'00000000'
		call	ra07
		movlw	B'00000001'
		call	ra07
		movlw	B'00000010'
		call	ra07
		movlw	B'00000011'
		call	ra07
		movlw	B'00000100'
		call	ra07
		movlw	B'00000101'
		call	ra07
		movlw	B'00000110'
		call	ra07

		return
;-----------------------------------------------------------------------
; xxxxxxxxxxxx get actual stage based on sensors and last stage xxxxxxxx
;-----------------------------------------------------------------------
get_stage	btfss	PORTA,D'006'
		goto	set_stage01		;independed of the past - stage = 01
		btfss	PORTA,D'005'
		goto	set_stage02		;independed of the past - stage = 02
		btfss	PORTA,D'004'
		goto	set_stage03		;independed of the past - stage = 31

;no sensor is active
		clrf	stage1
		clrf	stage2
		clrf	stage3
		bsf	stage3,D'006'		;no sensor active
		return
;-----------------------------------------------------------------------
set_stage01
;stage01 is active always, when Sensor RA6 is active
;first dblchk if there are no other active sensors
		clrf	stage1
		clrf	stage2
		clrf	stage3
		
		btfss	PORTA,D'005'
		goto	s_error
		btfss	PORTA,D'004'
		goto	s_error
		bsf	stage1,D'000'		;activate stage01
		return
;-----------------------------------------------------------------------
set_stage02
;stage03 is active always, when Sensor RA5 is active
;first dblchk if there are no other active sensors
		clrf	stage1
		clrf	stage2
		clrf	stage3
		
		btfss	PORTA,D'006'
		goto	s_error
		btfss	PORTA,D'004'
		goto	s_error
		bsf	stage1,D'001'		;activate stage02
		return
;-----------------------------------------------------------------------
set_stage03
;stage03 is active always, when Sensor RA4 is active
;first dblchk if there are no other active sensors
		clrf	stage1
		clrf	stage2
		clrf	stage3
		
		btfss	PORTA,D'006'
		goto	s_error
		btfss	PORTA,D'005'
		goto	s_error
		bsf	stage1,D'002'		;activate stage03
		return
;-----------------------------------------------------------------------
;error in sensors settings - more then one sensors are active at one time
s_error		clrf	stage1
		clrf	stage2
		clrf	stage3
		bsf	stage3,D'007'	;error stage
		return
;-----------------------------------------------------------------------
; xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;-----------------------------------------------------------------------

tmp01		movlw	B'00001111'
		call	rb07
		call	dr3
		movlw	B'00000111'
		call	rb07
		call	dr3
		movlw	B'00001111'
		call	rb07
		call	dr3
		movlw	B'00000111'
		call	rb07
		call	dr3
		movlw	B'00001111'
		call	rb07
		call	dr3
		movlw	B'00000111'
		call	rb07
		call	dr3
		movlw	B'00001111'
		call	rb07
		call	dr3
		movlw	B'00000111'
		call	rb07
		call	dr3
		movlw	B'00001111'
		call	rb07
		call	dr3
		movlw	B'00000111'
		call	rb07
		call	dr3
		movlw	B'00001111'
		call	rb07
		call	dr3
		movlw	B'00000111'
		call	rb07
		call	dr3
		movlw	B'00001111'
		call	rb07
		call	dr3
		movlw	B'00000111'
		call	rb07
		call	dr3

		return
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;initialize time-to-send counter
init_ttsc	movlw	D'255'
		movwf	ttsc1
		movwf	ttsc2
		movlw	D'010'
		movwf	ttsc3
		return
;----------------------------------------------------------------------------
;decrement time-to-send counter
ddtsc		clrf	v_send
		DECFSZ  ttsc1,F
		return
		movlw	D'255'
		movwf	ttsc1
		DECFSZ  ttsc2,F
		return
		movlw	D'255'
		movwf	ttsc2
		DECFSZ  ttsc3,F
		return
		call	init_ttsc
		bsf	v_send,D'000'
		return
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;sensor interactive test---  not used ---
mtt		btfss	PORTA,D'006'
		goto	q1
		call	set_ds1_red		

mtt2		btfss	PORTA,D'005'
		goto	q2
		call	set_ds2_red

mtt3		btfss	PORTA,D'004'
		goto	q3
		call	set_ds3_red
		goto	mtt

q1		call	set_ds1_green
		goto	mtt2
q2		call	set_ds2_green
		goto	mtt3
q3		call	set_ds3_green
		goto	mtt
;------------------------------------------------------------------------------

		END